@@ -39,6 +39,9 @@ fixtures = {
                     'min_ram': '512',
                     'min_disk': '10',
                     'properties': {'a': 'b', 'c': 'd'},
+                    'is_public': False,
+                    'protected': False,
+                    'deleted': False,
                 }},
             ),
         ),
@@ -141,6 +144,9 @@ fixtures = {
                 'x-image-meta-id': '1',
                 'x-image-meta-name': 'image-1',
                 'x-image-meta-property-arch': 'x86_64',
+                'x-image-meta-is_public': 'false',
+                'x-image-meta-protected': 'false',
+                'x-image-meta-deleted': 'false',
             },
             None),
         'GET': (
@@ -160,6 +166,8 @@ fixtures = {
                     'min_ram': '512',
                     'min_disk': '10',
                     'properties': {'a': 'b', 'c': 'd'},
+                    'is_public': False,
+                    'protected': False,
                 }},
             ),
         ),
@@ -215,8 +223,9 @@ class ImageManagerTest(unittest.TestCase):
         self.assertEqual(images[2].id, 'c')
 
     def test_list_with_limit_less_than_page_size(self):
-        list(self.mgr.list(page_size=20, limit=10))
-        expect = [('GET', '/v1/images/detail?limit=20', {}, None)]
+        results = list(self.mgr.list(page_size=2, limit=1))
+        expect = [('GET', '/v1/images/detail?limit=2', {}, None)]
+        self.assertEqual(1, len(results))
         self.assertEqual(self.api.calls, expect)
 
     def test_list_with_limit_greater_than_page_size(self):
@@ -246,6 +255,9 @@ class ImageManagerTest(unittest.TestCase):
         self.assertEqual(self.api.calls, expect)
         self.assertEqual(image.id, '1')
         self.assertEqual(image.name, 'image-1')
+        self.assertEqual(image.is_public, False)
+        self.assertEqual(image.protected, False)
+        self.assertEqual(image.deleted, False)
 
     def test_data(self):
         data = ''.join([b for b in self.mgr.data('1', do_checksum=False)])
@@ -325,9 +337,12 @@ class ImageManagerTest(unittest.TestCase):
         self.assertEqual(image.container_format, 'ovf')
         self.assertEqual(image.disk_format, 'vhd')
         self.assertEqual(image.owner, 'asdf')
-        self.assertEqual(image.size, '1024')
-        self.assertEqual(image.min_ram, '512')
-        self.assertEqual(image.min_disk, '10')
+        self.assertEqual(image.size, 1024)
+        self.assertEqual(image.min_ram, 512)
+        self.assertEqual(image.min_disk, 10)
+        self.assertEqual(image.is_public, False)
+        self.assertEqual(image.protected, False)
+        self.assertEqual(image.deleted, False)
         self.assertEqual(image.properties, {'a': 'b', 'c': 'd'})
 
     def test_create_with_data(self):
@@ -348,6 +363,7 @@ class ImageManagerTest(unittest.TestCase):
             'min_disk': 10,
             'copy_from': 'http://example.com',
             'properties': {'a': 'b', 'c': 'd'},
+            'deleted': False,
         }
         image = self.mgr.update('1', **fields)
         expect_hdrs = {
@@ -361,16 +377,20 @@ class ImageManagerTest(unittest.TestCase):
             'x-glance-api-copy-from': 'http://example.com',
             'x-image-meta-property-a': 'b',
             'x-image-meta-property-c': 'd',
+            'x-image-meta-deleted': 'False',
         }
         expect = [('PUT', '/v1/images/1', expect_hdrs, None)]
         self.assertEqual(self.api.calls, expect)
         self.assertEqual(image.id, '1')
         self.assertEqual(image.name, 'image-2')
+        self.assertEqual(image.size, 1024)
+        self.assertEqual(image.min_ram, 512)
+        self.assertEqual(image.min_disk, 10)
 
     def test_update_with_data(self):
         image_data = StringIO.StringIO('XXX')
         self.mgr.update('1', data=image_data)
-        expect_headers = {'x-image-meta-size': '3'}
+        expect_headers = {'x-image-meta-size': '3', 'Content-Length': 3}
         expect = [('PUT', '/v1/images/1', expect_headers, image_data)]
         self.assertEqual(self.api.calls, expect)
 
